Class: Timeprice::CpiPoint

Inherits:
Data
  • Object
show all
Defined in:
lib/timeprice/cpi_lookup.rb

Overview

CpiPoint pairs a CPI index value with the granularity of how it was resolved. See Granularity for the full set of possible tags.

Instance Attribute Summary collapse

Instance Attribute Details

#granularityObject (readonly)

Returns the value of attribute granularity

Returns:

  • (Object)

    the current value of granularity



9
10
11
# File 'lib/timeprice/cpi_lookup.rb', line 9

def granularity
  @granularity
end

#valueObject (readonly)

Returns the value of attribute value

Returns:

  • (Object)

    the current value of value



9
10
11
# File 'lib/timeprice/cpi_lookup.rb', line 9

def value
  @value
end