Class: Timeprice::CpiPoint
- Inherits:
-
Data
- Object
- Data
- Timeprice::CpiPoint
- Defined in:
- lib/timeprice/cpi_lookup.rb
Overview
CpiPoint pairs a CPI index value with the granularity of how it was resolved. See Granularity for the full set of possible tags.
Instance Attribute Summary collapse
-
#granularity ⇒ Object
readonly
Returns the value of attribute granularity.
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Instance Attribute Details
#granularity ⇒ Object (readonly)
Returns the value of attribute granularity
9 10 11 |
# File 'lib/timeprice/cpi_lookup.rb', line 9 def granularity @granularity end |
#value ⇒ Object (readonly)
Returns the value of attribute value
9 10 11 |
# File 'lib/timeprice/cpi_lookup.rb', line 9 def value @value end |